package gz.cyberbrain.cyberhotel.junit.tests;

import java.math.BigDecimal;
import java.util.Calendar;
import java.util.Collection;
import java.util.HashSet;
import java.util.Iterator;

import org.springframework.test.AbstractTransactionalDataSourceSpringContextTests;

import gz.cyberbrain.cyberhotel.junit.tests.facade.delegate.TestFacadeDelegate;
import gz.cyberbrain.cyberhotel.junit.tests.facade.delegate.TestFacadeDelegateFactory;
import gz.cyberbrain.cyberhotel.model.address.to.AddressTo;
import gz.cyberbrain.cyberhotel.model.bank.to.BankTo;
import gz.cyberbrain.cyberhotel.model.board.to.BoardTo;
import gz.cyberbrain.cyberhotel.model.card.to.CardTo;
import gz.cyberbrain.cyberhotel.model.concept.to.ConceptTo;
import gz.cyberbrain.cyberhotel.model.configurationfacade.delegate.ConfigurationFacadeDelegate;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.AddressInUseException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.BankWithClientsException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.BoardInUseException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.BoardTariffiedException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.CardWithClientsException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.ConceptInUseException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.PriceTypeInUseException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.PriceTypeTariffiedException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.RoomTypeInUseException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.RoomWithBoardersException;
import gz.cyberbrain.cyberhotel.model.configurationfacade.exceptions.UserInUseException;
import gz.cyberbrain.cyberhotel.model.day.to.DayTo;
import gz.cyberbrain.cyberhotel.model.employee.to.EmployeeTo;
import gz.cyberbrain.cyberhotel.model.price.to.PriceTo;
import gz.cyberbrain.cyberhotel.model.pricetype.to.PriceTypeTo;
import gz.cyberbrain.cyberhotel.model.role.to.RoleTo;
import gz.cyberbrain.cyberhotel.model.room.to.RoomTo;
import gz.cyberbrain.cyberhotel.model.roomtype.to.RoomTypeTo;
import gz.cyberbrain.cyberhotel.model.season.to.SeasonTo;
import gz.cyberbrain.cyberhotel.model.spring.facade.SpringFacadeFactory;
import gz.cyberbrain.cyberhotel.model.user.to.UserTo;
import gz.cyberbrain.cyberhotel.model.util.encrypt.PasswordEncrypter;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InstanceNotFoundException;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InternalErrorException;
import gz.cyberbrain.cyberhotel.model.util.money.MoneyOperations;
import gz.cyberbrain.cyberhotel.security.SecurityHandler;

public class ConfigurationFacadeDelegateTest extends AbstractTransactionalDataSourceSpringContextTests {

	private ConfigurationFacadeDelegate delegate;	
	private TestFacadeDelegate testDelegate;
	private AddressTo address;
	private BankTo bank;
	private CardTo card;
	private RoomTypeTo roomType;
	private RoomTo room;
	private BoardTo board;
	private PriceTypeTo priceType;
	private SeasonTo season;
	private PriceTo price;
	private DayTo day;
	private ConceptTo concept;
	private EmployeeTo employee;

	protected String[] getConfigLocations() {
		return new String[]{"../../Sources/applicationContext.xml"};
	}

	protected void onSetUpBeforeTransaction(){

		try {

			delegate =
				SpringFacadeFactory.getConfigurationFacadeDelegate();		

			testDelegate = TestFacadeDelegateFactory.getTestFacadeDelegate();	

			SecurityHandler.setSecureContext("admin", "admin");

			address = new AddressTo(null,"Espaa","A Corua","A Baa");
			address = delegate.createAddress(address);

			bank = new BankTo(null,"Banco Gallego", "BancoGallego.jpg");
			bank = delegate.createBank(bank);

			card = new CardTo(null,"MasterCard", "MasterCard.jpg");
			card = delegate.createCard(card);

			roomType = new RoomTypeTo("IN","Individual");
			roomType = delegate.createRoomType(roomType);

			room = new RoomTo("IN101","101",1,"IN","Libre","Limpa",Calendar.getInstance(),false,1,"");
			delegate.createRoom(room);

			board = new BoardTo("PC", "Pensin completa");
			board = delegate.createBoard(board);

			priceType = new PriceTypeTo("TIN","Tarifa Individual");
			priceType = delegate.createPriceType(priceType);

			concept = new ConceptTo("Gar","Garaxe",7);
			concept = delegate.createConcept(concept);	

			Calendar bornDate = Calendar.getInstance();
			Calendar hireDate = Calendar.getInstance();
			bornDate.set(1970,1-1,1,0,0,0);
			hireDate.set(2000,1-1,1,0,0,0);

			BigDecimal salary = new BigDecimal("1000.50");			
			employee = new EmployeeTo(null,"12345678X","Alberto","Gonzlez","Prez",bornDate,"H","Casado",address.getAddressId(),"AldeaX","n10","981880000","","Recepcionista",hireDate,salary,"Atento");			
			employee = delegate.createEmployee(employee);

			season = new SeasonTo(null,"Alta","Temporada Alta");
			season = delegate.createSeason(season);
			
			price = new PriceTo(new Long(1), new BigDecimal(35.50), "PC", "TIN", season.getSeasonId());
			delegate.createPrice(price);
			
			Calendar start = Calendar.getInstance();

			start.set(2006,6-1,1,0,0,0);
			day = new DayTo(start,season.getSeasonId());
			day = delegate.createDay(day);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	protected void onTearDownAfterTransaction(){

		try {

			delegate.deleteEmployee(employee);
			delegate.deleteAddress(address);
			delegate.deleteBank(bank);
			delegate.deleteCard(card);
			delegate.deleteRoom(room);	
			delegate.deleteRoomType(roomType);
			delegate.deletePrice(price);
			delegate.deleteBoard(board);
			delegate.deletePriceType(priceType);
			delegate.deleteSeason(season);			
			delegate.deleteDay(day);
			delegate.deleteConcept(concept);

			SecurityHandler.clearSecurityContext();

		} catch (ConceptInUseException e) {
			e.printStackTrace();
			fail();
		} catch (PriceTypeInUseException e) {
			e.printStackTrace();
			fail();
		} catch (PriceTypeTariffiedException e) {
			e.printStackTrace();
			fail();
		} catch (BoardInUseException e) {
			e.printStackTrace();
			fail();
		} catch (BoardTariffiedException e) {
			e.printStackTrace();
			fail();
		} catch (RoomWithBoardersException e) {
			e.printStackTrace();
			fail();
		} catch (RoomTypeInUseException e) {
			e.printStackTrace();
			fail();
		} catch (CardWithClientsException e) {
			e.printStackTrace();
			fail();
		} catch (BankWithClientsException e) {
			e.printStackTrace();
			fail();
		} catch (AddressInUseException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}		

	public void testRegisterUser() {

		try {

			RoleTo role = new RoleTo("ROLE_MANAGER");
			Collection<RoleTo>roles = new HashSet<RoleTo>();
			roles.add(role);

			UserTo manager = new UserTo("manager","badPass",null,roles);
			delegate.registerUser(manager);

			delegate.removeUser(manager);

		} catch (UserInUseException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testChangePassword() {

		try {

			RoleTo role = new RoleTo("ROLE_MANAGER");
			Collection<RoleTo>roles = new HashSet<RoleTo>();
			roles.add(role);

			UserTo manager = new UserTo("manager","badPass",null,roles);
			delegate.registerUser(manager);

			delegate.changePassword("manager", "manager");

			delegate.removeUser(manager);

		} catch (UserInUseException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}
	}

	public void testRemoveUser() {

		try {

			RoleTo role = new RoleTo("ROLE_MANAGER");
			Collection<RoleTo>roles = new HashSet<RoleTo>();
			roles.add(role);

			UserTo manager = new UserTo("manager","badPass",null,roles);
			delegate.registerUser(manager);

			delegate.removeUser(manager);

		} catch (UserInUseException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUsersList() {

		try {

			Collection users = delegate.usersList();
			Iterator iter = users.iterator();

			UserTo currentUser;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentUser = (UserTo) iter.next();

				test = currentUser.getLogin().equals("admin")
				&& currentUser.getPassword().equals(PasswordEncrypter.encrypt("admin","admin"))
				&& (currentUser.getEmployee() == null);

			}

			assertTrue("UsersList", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}
	}

	public void testRolesList() {

		try {

			Collection roles = delegate.rolesList();
			Iterator iter = roles.iterator();

			RoleTo currentRole;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentRole = (RoleTo) iter.next();				

				switch(i) {
				case 0:
					test = currentRole.getPrivilege().equals("ROLE_ADMIN");					
					break;
				case 1:
					test = test && currentRole.getPrivilege().equals("ROLE_MANAGER");					
					break;
				case 2:
					test = test && currentRole.getPrivilege().equals("ROLE_USER");
					break;
				}				

			}

			assertTrue("RolesList", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}
	}


	public void testCreateAddress(){

		try {

			AddressTo newAddress = new AddressTo(null,"Espaa", "A Corua", "Santa Comba");

			newAddress = delegate.createAddress(newAddress);

			AddressTo obtainedAddress = testDelegate.findAddress(newAddress.getAddressId());			

			boolean test = obtainedAddress.getAddressId().equals(newAddress.getAddressId()) 
			&& obtainedAddress.getCountry().equals(newAddress.getCountry())
			&& obtainedAddress.getProvince().equals(newAddress.getProvince())
			&& obtainedAddress.getLocality().equals(newAddress.getLocality());

			delegate.deleteAddress(newAddress);

			assertTrue("CreateAddress", test);

		} catch (AddressInUseException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUpdateAddress() {

		try {

			AddressTo obtainedAddress = testDelegate.findAddress(address.getAddressId());

			obtainedAddress.setLocality("Negreira");

			delegate.updateAddress(obtainedAddress);						

			AddressTo updatedAddress = testDelegate.findAddress(obtainedAddress.getAddressId());

			boolean test = updatedAddress.getAddressId().equals(obtainedAddress.getAddressId()) 
			&& updatedAddress.getCountry().equals(obtainedAddress.getCountry())
			&& updatedAddress.getProvince().equals(obtainedAddress.getProvince())
			&& updatedAddress.getLocality().equals("Negreira");

			assertTrue("UpdateAddress",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}


	public void testDeleteAddress() {

		try {

			AddressTo newAddress = new AddressTo(null, "Espaa", "A Corua", "Santiago de Compostela");

			newAddress = delegate.createAddress(newAddress);

			delegate.deleteAddress(newAddress);

			newAddress = testDelegate.findAddress(newAddress.getAddressId());
			
			assertTrue("DeleteAddress", false);

		} catch (AddressInUseException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			assertTrue("DeleteAddress", true);
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();
		}
	}

	public void testShowAddresses() {

		try {

			Collection addresses = delegate.showAddresses();
			Iterator iter = addresses.iterator();

			AddressTo currentAddress;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentAddress = (AddressTo) iter.next();

				test = currentAddress.getAddressId().equals(address.getAddressId()) 
				&& currentAddress.getCountry().equals(address.getCountry()) 
				&& currentAddress.getProvince().equals(address.getProvince())
				&& currentAddress.getLocality().equals(address.getLocality());

			}

			assertTrue("ShowAddresses", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		} 

	}

	public void testCreateBank() {

		try {

			BankTo newBank = new BankTo(null,"Caixa Galicia", "CaixaGalicia.jpg");

			newBank = delegate.createBank(newBank);

			BankTo obtainedBank = testDelegate.findBank(newBank.getBankId());

			boolean test = obtainedBank.getBankId().equals(newBank.getBankId()) 
			&& obtainedBank.getName().equals(newBank.getName())
			&& obtainedBank.getLogo().equals(newBank.getLogo());

			delegate.deleteBank(newBank);

			assertTrue("CreateBank", test);

		} catch (BankWithClientsException e) {
			e.printStackTrace();
			fail();	
		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUpdateBank() {

		try {

			BankTo obtainedBank = testDelegate.findBank(bank.getBankId());

			obtainedBank.setLogo("NovoLogo.jpg");

			delegate.updateBank(obtainedBank);

			BankTo updatedBank = testDelegate.findBank(obtainedBank.getBankId());

			boolean test = updatedBank.getBankId().equals(obtainedBank.getBankId()) 
			&& updatedBank.getName().equals(obtainedBank.getName())
			&& updatedBank.getLogo().equals("NovoLogo.jpg");

			assertTrue("UpdateBank",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testDeleteBank() {

		try {

			BankTo newBank = new BankTo(null, "La Caixa", "LaCaixaLogo.jpg");

			newBank = delegate.createBank(newBank);

			delegate.deleteBank(newBank);

			newBank = testDelegate.findBank(newBank.getBankId());
			
			assertTrue("DeleteBank", false);

		} catch (BankWithClientsException e) {
			e.printStackTrace();
			fail();			
		} catch (InstanceNotFoundException e) {
			assertTrue("DeleteBank", true);			
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();
		}
	}

	public void testShowBanks() {

		try {

			Collection banks = delegate.showBanks();

			Iterator iter = banks.iterator();

			BankTo currentBank;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentBank = (BankTo) iter.next();

				test = currentBank.getBankId().equals(bank.getBankId()) 
				&& currentBank.getName().equals(bank.getName()) 
				&& currentBank.getLogo().equals(bank.getLogo());

			}

			assertTrue("ShowBanks", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		} 

	}

	public void testCreateCard() {

		try {


			CardTo newCard = new CardTo(null,"4B", "4B.jpg");

			newCard = delegate.createCard(newCard);

			CardTo obtainedCard = testDelegate.findCard(newCard.getCardId());

			boolean test = obtainedCard.getCardId().equals(newCard.getCardId()) 
			&& obtainedCard.getType().equals(newCard.getType())
			&& obtainedCard.getLogo().equals(newCard.getLogo());

			delegate.deleteCard(newCard);

			assertTrue("CreateCard", test);

		} catch (CardWithClientsException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUpdateCard() {

		try {

			CardTo obtainedCard = testDelegate.findCard(card.getCardId());

			obtainedCard.setLogo("NovoLogo.jpg");

			delegate.updateCard(obtainedCard);

			CardTo updatedCard = testDelegate.findCard(obtainedCard.getCardId());

			boolean test = updatedCard.getCardId().equals(obtainedCard.getCardId()) 
			&& updatedCard.getType().equals(obtainedCard.getType())
			&& updatedCard.getLogo().equals("NovoLogo.jpg");

			assertTrue("UpdateCard",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testDeleteCard() {

		try {

			CardTo newCard = new CardTo(null, "Visa", "Visa.jpg");

			newCard = delegate.createCard(newCard);

			delegate.deleteCard(newCard);

			newCard = testDelegate.findCard(newCard.getCardId());
			
			assertTrue("DeleteCard", false);

		} catch (CardWithClientsException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			assertTrue("DeleteCard", true);		
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();
		}
	}

	public void testShowCards() {

		try {

			Collection cards = delegate.showCards();

			Iterator iter = cards.iterator();

			CardTo currentCard;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentCard = (CardTo) iter.next();

				test = currentCard.getCardId().equals(card.getCardId()) 
				&& currentCard.getType().equals(card.getType()) 
				&& currentCard.getLogo().equals(card.getLogo());

			}

			assertTrue("ShowCards", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		} 

	}


	public void testCreateRoomType() {

		try {


			RoomTypeTo newRoomType = new RoomTypeTo("DB","Doble");

			newRoomType = delegate.createRoomType(newRoomType);

			RoomTypeTo obtainedRoomType = testDelegate.findRoomType(newRoomType.getRoomTypeCode());

			boolean test = obtainedRoomType.getRoomTypeCode().equals(newRoomType.getRoomTypeCode()) 
			&& obtainedRoomType.getDescription().equals(newRoomType.getDescription());

			delegate.deleteRoomType(newRoomType);

			assertTrue("CreateRoomType", test);

		} catch (RoomTypeInUseException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUpdateRoomType() {

		try {

			RoomTypeTo obtainedRoomType = testDelegate.findRoomType(roomType.getRoomTypeCode());

			obtainedRoomType.setDescription("Habitacin Doble");

			delegate.updateRoomType(obtainedRoomType);

			RoomTypeTo updatedRoomType = testDelegate.findRoomType(obtainedRoomType.getRoomTypeCode());

			boolean test = updatedRoomType.getRoomTypeCode().equals(obtainedRoomType.getRoomTypeCode()) 
			&& updatedRoomType.getDescription().equals(obtainedRoomType.getDescription());

			assertTrue("UpdateRoomType",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testDeleteRoomType() {

		try {

			RoomTypeTo newRoomType = new RoomTypeTo("A","Apartamento");

			newRoomType = delegate.createRoomType(newRoomType);

			delegate.deleteRoomType(newRoomType);

			newRoomType = testDelegate.findRoomType(newRoomType.getRoomTypeCode());
			
			assertTrue("DeleteRoomType", false);

		} catch (RoomTypeInUseException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			assertTrue("DeleteRoomType", true);
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();
		}
	}

	public void testShowRoomTypes() {

		try {

			Collection roomTypes = delegate.showRoomTypes();

			Iterator iter = roomTypes.iterator();

			RoomTypeTo currentRoomType;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentRoomType = (RoomTypeTo) iter.next();

				test = currentRoomType.getRoomTypeCode().equals(roomType.getRoomTypeCode()) 
				&& currentRoomType.getDescription().equals(roomType.getDescription()); 

			}

			assertTrue("ShowRoomTypes", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		} 

	}

	public void testCreateRoom() {

		try {

			RoomTo newRoom = new RoomTo("IN102","102",1,"IN","Libre","Limpa",Calendar.getInstance(),false,1,"");

			delegate.createRoom(newRoom);

			RoomTo obtainedRoom = testDelegate.findRoom(newRoom.getRoomCode());

			boolean test = obtainedRoom.getRoomCode().equals(newRoom.getRoomCode()) 
			&& obtainedRoom.getNumber().equals(newRoom.getNumber())
			&& (obtainedRoom.getFloor() == newRoom.getFloor())
			&& obtainedRoom.getType().equals(newRoom.getType())
			&& obtainedRoom.getOccupancyStatus().equals(newRoom.getOccupancyStatus())
			&& obtainedRoom.getCleaningStatus().equals(newRoom.getCleaningStatus())
			&& obtainedRoom.getCheckingDate().equals(newRoom.getCheckingDate())
			&& (obtainedRoom.getSmokers() == newRoom.getSmokers())
			&& (obtainedRoom.getMaxPax() == newRoom.getMaxPax())
			&& obtainedRoom.getNotes().equals(newRoom.getNotes());

			delegate.deleteRoom(newRoom);

			assertTrue("CreateRoom", test);

		} catch (RoomWithBoardersException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUpdateRoom() {

		try {

			RoomTo obtainedRoom = testDelegate.findRoom(room.getRoomCode());

			obtainedRoom.setOccupancyStatus("Bloqueada");
			obtainedRoom.setNotes("Habitacin pendiente de desinfeccin");

			delegate.updateRoom(obtainedRoom);

			RoomTo updatedRoom = testDelegate.findRoom(obtainedRoom.getRoomCode());

			boolean test = updatedRoom.getRoomCode().equals(obtainedRoom.getRoomCode()) 
			&& updatedRoom.getNumber().equals(obtainedRoom.getNumber())
			&& (updatedRoom.getFloor() == obtainedRoom.getFloor())
			&& updatedRoom.getType().equals(obtainedRoom.getType())
			&& updatedRoom.getOccupancyStatus().equals("Bloqueada")
			&& updatedRoom.getCleaningStatus().equals(obtainedRoom.getCleaningStatus())
			&& updatedRoom.getCheckingDate().equals(obtainedRoom.getCheckingDate())
			&& (updatedRoom.getSmokers() == obtainedRoom.getSmokers())
			&& (updatedRoom.getMaxPax() == obtainedRoom.getMaxPax())
			&& updatedRoom.getNotes().equals("Habitacin pendiente de desinfeccin");

			assertTrue("UpdateRoom",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testDeleteRoom() {

		try {

			RoomTo newRoom = new RoomTo("IN201","201",2,"IN","Libre","Limpa",Calendar.getInstance(),false,1,"");

			delegate.createRoom(newRoom);

			delegate.deleteRoom(newRoom);

			newRoom = testDelegate.findRoom(newRoom.getRoomCode());
			
			assertTrue("DeleteRoom", false);

		} catch (RoomWithBoardersException e) {
			e.printStackTrace();
			fail();	
		} catch (InstanceNotFoundException e) {
			assertTrue("DeleteRoom", true);
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();		
		}
	}

	public void testShowRooms() {

		try {

			Collection rooms = delegate.showRooms();

			Iterator iter = rooms.iterator();

			RoomTo currentRoom;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentRoom = (RoomTo) iter.next();

				test = currentRoom.getRoomCode().equals(room.getRoomCode()) 
				&& currentRoom.getNumber().equals(room.getNumber())
				&& (currentRoom.getFloor() == room.getFloor())
				&& currentRoom.getType().equals(room.getType())
				&& currentRoom.getOccupancyStatus().equals(room.getOccupancyStatus())
				&& currentRoom.getCleaningStatus().equals(room.getCleaningStatus())
				&& (currentRoom.getCheckingDate().get(Calendar.DATE) == room.getCheckingDate().get(Calendar.DATE))
				&& (currentRoom.getSmokers() == room.getSmokers())
				&& (currentRoom.getMaxPax() == room.getMaxPax())
				&& currentRoom.getNotes().equals(room.getNotes());

			}

			assertTrue("ShowRooms", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		} 

	}


	public void testCreateBoard() {

		try {


			BoardTo newBoard = new BoardTo("AD","Alojamiento con Desayuno");

			newBoard = delegate.createBoard(newBoard);

			BoardTo obtainedBoard = testDelegate.findBoard(newBoard.getBoardCode());

			boolean test = obtainedBoard.getBoardCode().equals(newBoard.getBoardCode()) 
			&& obtainedBoard.getDescription().equals(newBoard.getDescription());

			delegate.deleteBoard(newBoard);

			assertTrue("CreateBoard", test);

		} catch (BoardInUseException e) {
			e.printStackTrace();
			fail();
		} catch (BoardTariffiedException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUpdateBoard() {

		try {

			BoardTo obtainedBoard = testDelegate.findBoard(board.getBoardCode());

			obtainedBoard.setDescription("Pensin Completa (Desayuno, comida, cena)");

			delegate.updateBoard(obtainedBoard);

			BoardTo updatedBoard = testDelegate.findBoard(obtainedBoard.getBoardCode());

			boolean test = updatedBoard.getBoardCode().equals(obtainedBoard.getBoardCode()) 
			&& updatedBoard.getDescription().equals(obtainedBoard.getDescription());

			assertTrue("UpdateBoard",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testDeleteBoard() {

		try {

			BoardTo newBoard = new BoardTo("MP","Media Pensin");

			newBoard = delegate.createBoard(newBoard);

			delegate.deleteBoard(newBoard);

			newBoard = testDelegate.findBoard(newBoard.getBoardCode());
			
			assertTrue("DeleteBoard", false);

		} catch (BoardInUseException e) {
			e.printStackTrace();
			fail();
		} catch (BoardTariffiedException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			assertTrue("DeleteBoard", true);			
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();
		}
	}

	public void testShowBoards() {

		try {

			Collection boards = delegate.showBoards();

			Iterator iter = boards.iterator();

			BoardTo currentBoard;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentBoard = (BoardTo) iter.next();

				test = currentBoard.getBoardCode().equals(board.getBoardCode()) 
				&& currentBoard.getDescription().equals(board.getDescription());
			}

			assertTrue("ShowBoards", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		} 

	}

	public void testCreatePriceType() {

		try {

			PriceTypeTo newPriceType = new PriceTypeTo("TDB","Tarifa Doble");

			newPriceType = delegate.createPriceType(newPriceType);

			PriceTypeTo obtainedPriceType = testDelegate.findPriceType(newPriceType.getPriceTypeCode());

			boolean test = obtainedPriceType.getPriceTypeCode().equals(newPriceType.getPriceTypeCode()) 
			&& obtainedPriceType.getDescription().equals(newPriceType.getDescription());

			delegate.deletePriceType(newPriceType);

			assertTrue("CreatePriceType", test);

		} catch (PriceTypeInUseException e) {
			e.printStackTrace();
			fail();
		} catch (PriceTypeTariffiedException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUpdatePriceType() {

		try {

			PriceTypeTo obtainedPriceType = testDelegate.findPriceType(priceType.getPriceTypeCode());

			obtainedPriceType.setDescription("Tarifa por persona");

			delegate.updatePriceType(obtainedPriceType);

			PriceTypeTo updatedPriceType = testDelegate.findPriceType(obtainedPriceType.getPriceTypeCode());

			boolean test = updatedPriceType.getPriceTypeCode().equals(obtainedPriceType.getPriceTypeCode()) 
			&& updatedPriceType.getDescription().equals(obtainedPriceType.getDescription());

			assertTrue("UpdatePriceType",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testDeletePriceType() {

		try {

			PriceTypeTo newPriceType = new PriceTypeTo("TDB","Tarifa doble");

			newPriceType = delegate.createPriceType(newPriceType);

			delegate.deletePriceType(newPriceType);

			newPriceType = testDelegate.findPriceType(newPriceType.getPriceTypeCode());
			
			assertTrue("DeletePriceType", false);

		} catch (PriceTypeInUseException e) {
			e.printStackTrace();
			fail();
		} catch (PriceTypeTariffiedException e) {
			e.printStackTrace();
			fail();			
		} catch (InstanceNotFoundException e) {
			assertTrue("DeletePriceType", true);			
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();
		}
	}

	public void testShowPriceTypes() {

		try {

			Collection priceTypes = delegate.showPriceTypes();

			Iterator iter = priceTypes.iterator();

			PriceTypeTo currentPriceType;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentPriceType = (PriceTypeTo) iter.next();

				test = currentPriceType.getPriceTypeCode().equals(priceType.getPriceTypeCode()) 
				&& currentPriceType.getDescription().equals(priceType.getDescription());
			}

			assertTrue("ShowPriceTypes", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		} 

	}

	public void testCreateSeason() {

		try {

			SeasonTo newSeason = new SeasonTo(null,"Media","Temporada Media");

			newSeason = delegate.createSeason(newSeason);
			SeasonTo obtainedSeason = testDelegate.findSeason(newSeason.getSeasonId());

			boolean test = obtainedSeason.getSeasonId().equals(newSeason.getSeasonId()) 
			&& obtainedSeason.getDescription().equals(newSeason.getDescription());

			delegate.deleteSeason(newSeason);

			assertTrue("CreateSeason", test);

		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUpdateSeason() {

		try {

			SeasonTo obtainedSeason = testDelegate.findSeason(season.getSeasonId());

			obtainedSeason.setDescription("Temporada Alta (Verano)");

			delegate.updateSeason(obtainedSeason);

			SeasonTo updatedSeason = testDelegate.findSeason(obtainedSeason.getSeasonId());

			boolean test = updatedSeason.getSeasonId().equals(obtainedSeason.getSeasonId())
			&& updatedSeason.getDescription().equals(obtainedSeason.getDescription());

			assertTrue("UpdateSeason",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testDeleteSeason() {

		try {

			SeasonTo newSeason = new SeasonTo(null,"Baja","Temporada Baja");

			newSeason = delegate.createSeason(newSeason);

			delegate.deleteSeason(newSeason);

			newSeason = testDelegate.findSeason(newSeason.getSeasonId());
			
			assertTrue("DeleteSeason", false);

		} catch (InstanceNotFoundException e) {
			assertTrue("DeleteSeason", true);			
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();
		}
	}

	public void testShowSeasons() {

		try {

			Collection seasons = delegate.showSeasons();

			Iterator iter = seasons.iterator();

			SeasonTo currentSeason;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentSeason = (SeasonTo) iter.next();

				test = currentSeason.getSeasonId().equals(season.getSeasonId()) 
				&& currentSeason.getDescription().equals(season.getDescription());

			}

			assertTrue("ShowSeasons", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		} 

	}

	public void testCreatePrice() {

		try {
		
			PriceTo obtainedPrice = testDelegate.findPrice(price.getPriceId(), price.getBoard(), price.getPriceType(), price.getSeason());
						
			boolean test = obtainedPrice.getPriceId().equals(price.getPriceId()) 
			&& MoneyOperations.getDecimalReduction(obtainedPrice.getValue()).equals(MoneyOperations.getDecimalReduction(price.getValue()))
			&& obtainedPrice.getBoard().equals(price.getBoard())
			&& obtainedPrice.getPriceType().equals(price.getPriceType())
			&& obtainedPrice.getSeason().equals(price.getSeason());									
			
			assertTrue("CreatePrice", test);

		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}
	
	public void testUpdatePrice() {

		try {

			PriceTo obtainedPrice = testDelegate.findPrice(price.getPriceId(), price.getBoard(), price.getPriceType(), price.getSeason());

			obtainedPrice.setValue(new BigDecimal(40));

			delegate.updatePrice(obtainedPrice);

			PriceTo updatedPrice = testDelegate.findPrice(obtainedPrice.getPriceId(), obtainedPrice.getBoard(), obtainedPrice.getPriceType(), obtainedPrice.getSeason());

			boolean test = updatedPrice.getPriceId().equals(obtainedPrice.getPriceId())
			&& MoneyOperations.getDecimalReduction(updatedPrice.getValue()).equals(MoneyOperations.getDecimalReduction(obtainedPrice.getValue()))
			&& updatedPrice.getBoard().equals(obtainedPrice.getBoard())
			&& updatedPrice.getPriceType().equals(obtainedPrice.getPriceType())
			&& updatedPrice.getSeason().equals(obtainedPrice.getSeason());

			assertTrue("UpdatePrice",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}
	
	public void testDeletePrice() {

		try {

			PriceTo newPrice = new PriceTo(new Long(2), new BigDecimal(4), "PC", "TIN", season.getSeasonId());

			delegate.createPrice(newPrice);

			delegate.deletePrice(newPrice);

			newPrice = testDelegate.findPrice(newPrice.getPriceId(), newPrice.getBoard(), newPrice.getPriceType(), newPrice.getSeason());
			
			assertTrue("DeletePrice", false);

		} catch (InstanceNotFoundException e) {
			assertTrue("DeletePrice", true);			
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();
		}
	}
	

	public void testCreateDay() {

		try {

			Calendar start = Calendar.getInstance();			
			start.set(2006,10-1,1,0,0,0);

			DayTo newDay = new DayTo(start,season.getSeasonId());

			newDay = delegate.createDay(newDay);

			DayTo obtainedDay = testDelegate.findDay(newDay.getDayDate());

			boolean test = obtainedDay.getDayDate().equals(newDay.getDayDate()) 
			&& obtainedDay.getDayDate().equals(newDay.getDayDate())			
			&& obtainedDay.getSeason().equals(newDay.getSeason());

			delegate.deleteDay(newDay);

			assertTrue("CreateDay", test);

		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUpdateDay() {

		try {

			DayTo obtainedDay = testDelegate.findDay(day.getDayDate());
			
			obtainedDay.setSeason(new Long(1));

			delegate.updateDay(obtainedDay);

			DayTo updatedDay = testDelegate.findDay(obtainedDay.getDayDate());

			boolean test = updatedDay.getDayDate().equals(obtainedDay.getDayDate())
			&& updatedDay.getDayDate().equals(obtainedDay.getDayDate())			
			&& updatedDay.getSeason().equals(obtainedDay.getSeason());

			assertTrue("UpdateDay",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testDeleteDay() {

		try {

			Calendar start = Calendar.getInstance();			
			start.set(2007,2-1,1,0,0,0);

			DayTo newDay = new DayTo(start,season.getSeasonId());

			newDay = delegate.createDay(newDay);

			delegate.deleteDay(newDay);

			newDay = testDelegate.findDay(newDay.getDayDate());
			
			assertTrue("DeleteDay", false);

		} catch (InstanceNotFoundException e) {
			assertTrue("DeleteDay", true);			
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();
		}
	}

	public void testShowDays() {

		try {

			Collection days = delegate.showDays();

			Iterator iter = days.iterator();

			DayTo currentDay;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentDay = (DayTo) iter.next();

				test = currentDay.getDayDate().equals(day.getDayDate()) 
				&& currentDay.getDayDate().equals(day.getDayDate())
				&& currentDay.getSeason().equals(day.getSeason());

			}

			assertTrue("ShowDays", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		} 

	}

	public void testCreateConcept() {

		try {

			ConceptTo newConcept = new ConceptTo("GAR","Garaje",7);

			newConcept = delegate.createConcept(newConcept);

			ConceptTo obtainedConcept = testDelegate.findConcept(newConcept.getConceptCode());

			boolean test = obtainedConcept.getConceptCode().equals(newConcept.getConceptCode()) 
			&& obtainedConcept.getDenomination().equals(newConcept.getDenomination())
			&& (obtainedConcept.getVat() == newConcept.getVat());

			delegate.deleteConcept(newConcept);

			assertTrue("CreateConcept", test);

		} catch (ConceptInUseException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUpdateConcept() {

		try {

			ConceptTo obtainedConcept = testDelegate.findConcept(concept.getConceptCode());

			obtainedConcept.setVat(4);

			delegate.updateConcept(obtainedConcept);

			ConceptTo updatedConcept = testDelegate.findConcept(obtainedConcept.getConceptCode());

			boolean test = updatedConcept.getConceptCode().equals(obtainedConcept.getConceptCode())
			&& updatedConcept.getDenomination().equals(obtainedConcept.getDenomination())
			&& (updatedConcept.getVat() == obtainedConcept.getVat());

			assertTrue("UpdateConcept",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testDeleteConcept() {

		try {

			ConceptTo newConcept = new ConceptTo("BAR","Minibar",7);

			newConcept = delegate.createConcept(newConcept);

			delegate.deleteConcept(newConcept);

			newConcept = testDelegate.findConcept(newConcept.getConceptCode());

			assertTrue("DeleteConcept", false);
			
		} catch (ConceptInUseException e) {
			e.printStackTrace();
			fail();
		} catch (InstanceNotFoundException e) {
			assertTrue("DeleteConcept", true);			
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();
		}
	}

	public void testShowConcepts() {

		try {

			Collection concepts = delegate.showConcepts();

			Iterator iter = concepts.iterator();

			ConceptTo currentConcept;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentConcept = (ConceptTo) iter.next();

				test = currentConcept.getConceptCode().equals(concept.getConceptCode()) 
				&& currentConcept.getDenomination().equals(concept.getDenomination())
				&& (currentConcept.getVat() == concept.getVat());

			}

			assertTrue("ShowConcepts", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		} 

	}

	public void testCreateEmployee() {

		try {

			Calendar bornDate = Calendar.getInstance();
			Calendar hireDate = Calendar.getInstance();

			bornDate.set(1972,10-1,1,0,0,0);
			hireDate.set(2007,1-1,31,23,59,59);

			BigDecimal salary = new BigDecimal("1200");

			EmployeeTo newEmployee = new EmployeeTo(null,"00000000X","Rosa","Gonzlez","Prez",bornDate,"H","Casado",address.getAddressId(),"AldeaX","n10","981880000","","Ama de chaves",hireDate,salary,"Traballadora");

			newEmployee = delegate.createEmployee(newEmployee);

			EmployeeTo obtainedEmployee = testDelegate.findEmployee(newEmployee.getEmployeeId());			

			boolean test = obtainedEmployee.getEmployeeId().equals(newEmployee.getEmployeeId()) 
			&& obtainedEmployee.getNif().equals(newEmployee.getNif())
			&& obtainedEmployee.getName().equals(newEmployee.getName())
			&& obtainedEmployee.getFirstSurname().equals(newEmployee.getFirstSurname())
			&& obtainedEmployee.getSecondSurname().equals(newEmployee.getSecondSurname())
			&& obtainedEmployee.getBornDate().equals(newEmployee.getBornDate())
			&& obtainedEmployee.getSex().equals(newEmployee.getSex())
			&& obtainedEmployee.getMaritalStatus().equals(newEmployee.getMaritalStatus())
			&& obtainedEmployee.getAddress().equals(newEmployee.getAddress())
			&& obtainedEmployee.getStreet().equals(newEmployee.getStreet())
			&& obtainedEmployee.getDwellingPlace().equals(newEmployee.getDwellingPlace())
			&& obtainedEmployee.getPhone1().equals(newEmployee.getPhone1())
			&& obtainedEmployee.getPhone2().equals(newEmployee.getPhone2())
			&& obtainedEmployee.getJob().equals(newEmployee.getJob())
			&& obtainedEmployee.getHireDate().equals(newEmployee.getHireDate())
			&& obtainedEmployee.getSalary().equals(newEmployee.getSalary())
			&& obtainedEmployee.getObservations().equals(newEmployee.getObservations());

			delegate.deleteEmployee(newEmployee);

			assertTrue("CreateEmployee", test);

		} catch (InstanceNotFoundException e) {
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testUpdateEmployee() {

		try {

			EmployeeTo obtainedEmployee = testDelegate.findEmployee(employee.getEmployeeId());

			BigDecimal newSalary = new BigDecimal("1100.10");

			obtainedEmployee.setSalary(newSalary);

			delegate.updateEmployee(obtainedEmployee);

			EmployeeTo updatedEmployee = testDelegate.findEmployee(obtainedEmployee.getEmployeeId());			

			boolean test = updatedEmployee.getEmployeeId().equals(obtainedEmployee.getEmployeeId())
			&& updatedEmployee.getNif().equals(obtainedEmployee.getNif())
			&& updatedEmployee.getName().equals(obtainedEmployee.getName())
			&& updatedEmployee.getFirstSurname().equals(obtainedEmployee.getFirstSurname())
			&& updatedEmployee.getSecondSurname().equals(obtainedEmployee.getSecondSurname())
			&& updatedEmployee.getBornDate().equals(obtainedEmployee.getBornDate())
			&& updatedEmployee.getSex().equals(obtainedEmployee.getSex())
			&& updatedEmployee.getMaritalStatus().equals(obtainedEmployee.getMaritalStatus())
			&& updatedEmployee.getAddress().equals(obtainedEmployee.getAddress())
			&& updatedEmployee.getStreet().equals(obtainedEmployee.getStreet())
			&& updatedEmployee.getDwellingPlace().equals(obtainedEmployee.getDwellingPlace())
			&& updatedEmployee.getPhone1().equals(obtainedEmployee.getPhone1())
			&& updatedEmployee.getPhone2().equals(obtainedEmployee.getPhone2())
			&& updatedEmployee.getJob().equals(obtainedEmployee.getJob())
			&& updatedEmployee.getHireDate().equals(obtainedEmployee.getHireDate())
			&& updatedEmployee.getSalary().equals(newSalary)
			&& updatedEmployee.getObservations().equals(obtainedEmployee.getObservations());

			assertTrue("UpdateEmployee",test);

		} catch (InstanceNotFoundException e){
			e.printStackTrace();
			fail();
		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		}

	}

	public void testDeleteEmployee() {

		try {

			Calendar bornDate = Calendar.getInstance();
			Calendar hireDate = Calendar.getInstance();

			bornDate.set(1980,2-1,1,0,0,0);
			hireDate.set(2007,5-1,31,23,59,59);

			BigDecimal salary = new BigDecimal("550.75");

			EmployeeTo newEmployee = new EmployeeTo(null,"11001100X","Fernando","Gonzlez","Prez",bornDate,"H","Casado",address.getAddressId(),"AldeaX","n10","981880000","","Botones",hireDate,salary,"Rpido");

			newEmployee = delegate.createEmployee(newEmployee);

			delegate.deleteEmployee(newEmployee);

			newEmployee = testDelegate.findEmployee(newEmployee.getEmployeeId());
			
			assertTrue("DeleteEmployee", false);

		} catch (InstanceNotFoundException e) {
			assertTrue("DeleteEmployee", true);			
		} catch (InternalErrorException e) {			
			e.printStackTrace();
			fail();
		}
	}

	public void testShowEmployees() {

		try {

			Collection employees = delegate.showEmployees();

			Iterator iter = employees.iterator();

			EmployeeTo currentEmployee;

			boolean test = true;

			for (int i=0; iter.hasNext();i++) {

				currentEmployee = (EmployeeTo) iter.next();

				test = currentEmployee.getEmployeeId().equals(employee.getEmployeeId()) 
				&& currentEmployee.getNif().equals(employee.getNif())
				&& currentEmployee.getName().equals(employee.getName())
				&& currentEmployee.getFirstSurname().equals(employee.getFirstSurname())
				&& currentEmployee.getSecondSurname().equals(employee.getSecondSurname())
				&& currentEmployee.getBornDate().equals(employee.getBornDate())
				&& currentEmployee.getSex().equals(employee.getSex())
				&& currentEmployee.getMaritalStatus().equals(employee.getMaritalStatus())
				&& currentEmployee.getAddress().equals(employee.getAddress())
				&& currentEmployee.getStreet().equals(employee.getStreet())
				&& currentEmployee.getDwellingPlace().equals(employee.getDwellingPlace())
				&& currentEmployee.getPhone1().equals(employee.getPhone1())
				&& currentEmployee.getPhone2().equals(employee.getPhone2())
				&& currentEmployee.getJob().equals(employee.getJob())
				&& currentEmployee.getHireDate().equals(employee.getHireDate())
				&& MoneyOperations.getDecimalReduction(currentEmployee.getSalary()).equals(employee.getSalary())
				&& currentEmployee.getObservations().equals(employee.getObservations());

			}

			assertTrue("ShowEmployees", test);

		} catch (InternalErrorException e) {
			e.printStackTrace();
			fail();
		} 

	}

}
