package gz.cyberbrain.cyberhotel.model.address.dao;

import gz.cyberbrain.cyberhotel.model.address.to.AddressTo;
import gz.cyberbrain.cyberhotel.model.spring.dao.AbstractSpringDao;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InstanceNotFoundException;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InternalErrorException;

import java.io.Serializable;
import java.util.Collection;
import java.util.Iterator;

public class AddressSpringDao extends AbstractSpringDao implements AddressDao {
	
	public AddressSpringDao() {
		super(AddressTo.class);
	}	

	public AddressTo create(AddressTo addressTo) throws InternalErrorException {		

		return (AddressTo) super.save(addressTo);

	}

	public AddressTo find(Long addressId) throws InstanceNotFoundException, InternalErrorException {

		AddressTo addressTo = (AddressTo) super.find(addressId);
		return addressTo;

	}

	public void update(AddressTo addressTo) throws InternalErrorException {		

		super.update(addressTo);

	}

	public void remove(AddressTo addressTo) throws InternalErrorException {

			super.delete(addressTo);
	
	}
	
	public Collection findAll() throws InternalErrorException {
		
		String queryName = "allAddresses";
		return super.findByQuery(queryName);
		
	}
	
	public Collection findCountries() throws InternalErrorException {
		String queryName = "allCountries";
		return super.findByQuery(queryName);
	}
	
	public Collection findProvincesByCountry(String country) throws InternalErrorException {
		String queryName = "provincesByCountry";
		return super.findByAttribute(queryName, country);
	}
	
	public Collection findLocalitiesByProvince(String country, String province) throws InternalErrorException {
		String queryName = "localitiesByProvince";
		Serializable []attributes = {country, province};
		return super.findByAttributes(queryName, attributes);
	}
	
	public Collection findByCountry(String country) throws InternalErrorException {
		String queryName = "findByCountry";
		return super.findByAttribute(queryName, country);
	}
	
	public Collection findByProvince(String country, String province) throws InternalErrorException {
		String queryName = "findByProvince";
		Serializable []attributes = {country, province}; 
		return super.findByAttributes(queryName, attributes);
	}
	
	public AddressTo findByLocality(String country, String province, String locality) throws InstanceNotFoundException, InternalErrorException {

		String queryName = "findByLocality";
		Serializable []attributes = {country, province, locality};
		Collection addressTo = super.findByAttributes(queryName, attributes);
		

		Exception e = new Exception("Address must be unique");

		if (addressTo.size() > 1) throw new InternalErrorException(e);
		if (addressTo.isEmpty()) throw new InstanceNotFoundException(attributes,AddressTo.class.getName());

		Iterator iter = addressTo.iterator();

		return (AddressTo) iter.next();

	}
	
	public AddressTo findByCompleteAddress(String country, String province, String locality) throws InstanceNotFoundException, InternalErrorException {
		
		String queryName = "findByCompleteAddress";
		Serializable []attributes = {country, province, locality};
		Collection addressTo = super.findByAttributes(queryName, attributes);
		
		Exception e = new Exception("Address must be unique");

		if (addressTo.size() > 1) throw new InternalErrorException(e);
		if (addressTo.isEmpty()) throw new InstanceNotFoundException(attributes,AddressTo.class.getName());

		Iterator iter = addressTo.iterator();

		return (AddressTo) iter.next();
		
	}
	
	public boolean existClients(Long addressId, String country) throws InternalErrorException {
		String queryName = "addressClients";
		Serializable []attributes = {addressId, country};
		return (!super.findByAttributes(queryName, attributes).isEmpty());
	}	
	
}
