package gz.cyberbrain.cyberhotel.model.configurationfacade.spring.actions;

import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

import gz.cyberbrain.cyberhotel.model.concept.dao.ConceptDao;
import gz.cyberbrain.cyberhotel.model.concept.to.ConceptTo;
import gz.cyberbrain.cyberhotel.model.day.dao.DayDao;
import gz.cyberbrain.cyberhotel.model.day.to.DayTo;
import gz.cyberbrain.cyberhotel.model.owe.dao.OweDao;
import gz.cyberbrain.cyberhotel.model.owe.to.OweTo;
import gz.cyberbrain.cyberhotel.model.price.dao.PriceDao;
import gz.cyberbrain.cyberhotel.model.price.to.PriceTo;
import gz.cyberbrain.cyberhotel.model.request.dao.RequestDao;
import gz.cyberbrain.cyberhotel.model.request.to.RequestTo;
import gz.cyberbrain.cyberhotel.model.util.config.ConfigurationHandler;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InstanceNotFoundException;
import gz.cyberbrain.cyberhotel.model.util.exceptions.InternalErrorException;
import gz.cyberbrain.cyberhotel.model.util.money.MoneyOperations;

public class UpdateDaySeasonAction {

	private DayDao dayDao;
	private OweDao oweDao;
	private ConceptDao conceptDao;
	private RequestDao requestDao;
	private PriceDao priceDao;
	private DayTo dayTo;

	public UpdateDaySeasonAction (DayDao dayDao, OweDao oweDao, ConceptDao conceptDao, RequestDao requestDao, PriceDao priceDao, DayTo dayTo) {

		this.dayDao = dayDao;
		this.oweDao = oweDao;
		this.conceptDao = conceptDao;
		this.requestDao = requestDao;
		this.priceDao = priceDao;
		this.dayTo = dayTo;

	}

	public void execute() throws InstanceNotFoundException, InternalErrorException {

		//Find owes by date

		Collection owes = oweDao.findByDate(dayTo.getDayDate());
		//System.out.println("There are " + owes.size());
		Iterator iter = owes.iterator();
		
		//Set the stay vat value
		
		ConceptTo conceptTo = conceptDao.find(ConfigurationHandler.STAY_CONCEPT);
		BigDecimal vat = conceptTo.getVat();	

		//Update owes price, vat and amount
		for(int i=0; iter.hasNext(); i++) { 
			
			OweTo currentOwe = (OweTo) iter.next();
			if (currentOwe.getConcept().equals(ConfigurationHandler.STAY_CONCEPT)) { //Is a stay owe
				
				RequestTo oweRequest = requestDao.find(oweDao.findOweReservation(currentOwe.getOweDate(), currentOwe.getRoom()), currentOwe.getParticular());
				PriceTo owePrice = priceDao.find(new Long(1), oweRequest.getBoard(), oweRequest.getPriceType(), dayTo.getSeason());
				currentOwe.setPrice(owePrice.getValue());
				currentOwe.setVat(vat);
				currentOwe.setAmount(MoneyOperations.getPriceWithVat(owePrice.getValue(), vat));
				oweDao.update(currentOwe);
				
			}
		}

		dayDao.update(dayTo);
		
	}
}
