package gz.cyberbrain.cyberhotel.view.swing.edit;

import javax.swing.JPanel;

import java.awt.Color; 
import java.awt.Toolkit;

import javax.swing.JLabel;
import java.awt.Rectangle;
import java.io.Serializable;
import java.util.HashMap;

import gz.cyberbrain.cyberhotel.controller.SaveAdapter;
import gz.cyberbrain.cyberhotel.controller.util.ErrorsHandler;
import gz.cyberbrain.cyberhotel.view.swing.FillableWindow;
import gz.cyberbrain.cyberhotel.view.swing.util.locale.Locale;

import javax.swing.JInternalFrame;
import javax.swing.JOptionPane;
import javax.swing.JTextField;
import javax.swing.JButton;
import javax.swing.UIManager;

import gz.cyberbrain.cyberhotel.view.swing.util.gui.InfoPanel;
import javax.swing.border.LineBorder;

public class SeasonWindow extends FillableWindow {

	private static final long serialVersionUID = 1L;
	private static SeasonWindow seasonWindow = null;
	private Serializable id = null;
	private JInternalFrame owner = null;
	private String dialogMessage = null;
	private String dialogTitle = null;
	private SaveAdapter saveAdapter = null;
	private JPanel jContentPane = null;
	private JLabel nameLabel = null;
	private JTextField nameTextField = null;
	private JLabel descLabel = null;
	private JTextField descTextField = null;
	private JButton saveButton = null;
	private JButton cancelButton = null;
	private InfoPanel infoPanel = null;
	
	/**
	 * @param owner
	 */
	private SeasonWindow() {
		super("", false, true, false, true);
		initialize();
	}

	public static SeasonWindow getInstance() {
		if (seasonWindow == null) seasonWindow = new SeasonWindow();
		return seasonWindow;
	}

	public void setAdapter(SaveAdapter saveAdapter) {
		this.saveAdapter = saveAdapter;
	}

	public SaveAdapter getAdapter() {
		return saveAdapter;
	}

	public String getDialogMessage() {
		return dialogMessage;
	}

	public void setDialogMessage(String dialogMessage) {
		this.dialogMessage = dialogMessage;
	}

	public String getDialogTitle() {
		return dialogTitle;
	}

	public void setDialogTitle(String dialogTitle) {
		this.dialogTitle = dialogTitle;
	}

	public JInternalFrame getOwner() {
		return owner;
	}

	public void setOwner(JInternalFrame owner) {
		this.owner = owner;
	}


	public void setId(Serializable id) {
		this.id = id;
	}

	public Serializable getId() {
		return id;
	}

	/**
	 * This method initializes this
	 * 
	 * @return void
	 */
	private void initialize() {
		this.setSize(630, 172);
		this.setLocation(387,0);
		this.setResizable(false);
		this.setContentPane(getJContentPane());		
		this.setDefaultCloseOperation(DISPOSE_ON_CLOSE);
		this.addInternalFrameListener(new javax.swing.event.InternalFrameAdapter()
		{
			public void internalFrameClosed(javax.swing.event.InternalFrameEvent evt)
			{
				(SeasonWindow.getInstance()).clean();
				(SeasonWindow.getInstance()).dispose();

			}
		});	
	}

	/**
	 * This method initializes jContentPane	
	 * 	
	 * @return javax.swing.JPanel	
	 */
	private JPanel getJContentPane() {
		if (jContentPane == null) {

			descLabel = new JLabel();
			descLabel.setBounds(new Rectangle(135, 70, 58, 16));
			descLabel.setText(Locale.get("SeasonWindow.descLabel"));
			nameLabel = new JLabel();
			nameLabel.setBounds(new Rectangle(14, 70, 52, 16));
			nameLabel.setText(Locale.get("SeasonWindow.nameLabel"));
			jContentPane = new JPanel();
			jContentPane.setLayout(null);
			jContentPane.add(nameLabel, null);
			jContentPane.add(getNameTextField(), null);
			jContentPane.add(descLabel, null);
			jContentPane.add(getDescTextField(), null);
			jContentPane.add(getSaveButton(), null);
			jContentPane.add(getCancelButton(), null);
			jContentPane.add(getInfoPanel(), null);
		}
		return jContentPane;
	}

	/**
	 * This method initializes nameTextField	
	 * 	
	 * @return javax.swing.JTextField	
	 */
	private JTextField getNameTextField() {
		if (nameTextField == null) {
			nameTextField = new JTextField();
			nameTextField.setBounds(new Rectangle(73, 70, 57, 19));
		}
		return nameTextField;
	}

	/**
	 * This method initializes descTextField	
	 * 	
	 * @return javax.swing.JTextField	
	 */
	private JTextField getDescTextField() {
		if (descTextField == null) {
			descTextField = new JTextField();
			descTextField.setBounds(new Rectangle(198, 70, 415, 19));
		}
		return descTextField;
	}

	/**
	 * This method initializes saveButton	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getSaveButton() {
		if (saveButton == null) {
			saveButton = new JButton();
			saveButton.setBounds(new Rectangle(413, 107, 93, 19));
			saveButton.setText(Locale.get("SeasonWindow.saveButton"));
			saveButton.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					HashMap<String, Object> attrs = new HashMap<String, Object>();
					attrs.put("id",getId());
					attrs.put("name", getNameTextField().getText());
					attrs.put("description", getDescTextField().getText());

					String message = getDialogMessage();
					String title = getDialogTitle();

					getAdapter().save(attrs);

					if (!inputErrors()) {

						Object[] options = {Locale.get("JOptionPane.Ok")};
						int n = JOptionPane.showOptionDialog(SeasonWindow.getInstance(),
								message,
								title,
								JOptionPane.OK_OPTION,
								JOptionPane.INFORMATION_MESSAGE,
								null,
								options,
								options[0]);

						if (n == JOptionPane.OK_OPTION) {
							ListWindow listWindow = (ListWindow) getOwner();
							listWindow.loadList();
							clean();
							dispose();	                    	
						}

					}

				}

			});

		}
		return saveButton;
	}

	/**
	 * This method initializes cancelButton	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getCancelButton() {
		if (cancelButton == null) {
			cancelButton = new JButton();
			cancelButton.setBounds(new Rectangle(520, 107, 93, 19));
			cancelButton.setText(Locale.get("SeasonWindow.cancelButton"));
			cancelButton.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					(SeasonWindow.getInstance()).clean();
					(SeasonWindow.getInstance()).dispose();

				}
			});
		}
		return cancelButton;
	}

	/**
	 * This method initializes infoPanel	
	 * 	
	 * @return javax.swing.JPanel	
	 */
	private InfoPanel getInfoPanel() {
		if (infoPanel == null) {
			infoPanel = new InfoPanel();
			infoPanel.setBounds(0,0,this.getWidth(),50);
		}
		return infoPanel;
	}


	public void setInfoPanel(InfoPanel ipanel) {		  

		jContentPane.remove(infoPanel);
		infoPanel = ipanel;
		jContentPane.add(infoPanel);

	}

	public void clean() {

		getInfoPanel().setInfoText(getInfoPanel().getInfoText());
		getNameTextField().setText("");;
		getDescTextField().setText("");
		getNameTextField().setBorder(UIManager.getBorder("TextField.border"));
	}

	public void fill(HashMap fields) {

		getNameTextField().setText((String) fields.get("name"));
		getDescTextField().setText((String) fields.get("description"));

	}

	private boolean inputErrors() {

		if (!ErrorsHandler.getErrors().isEmpty()) {

			if (ErrorsHandler.getErrorAt(0).getItem().equals("name")) {
				getInfoPanel().setErrorText("<html>" + Locale.get("InfoPanel.errors.title") + "<br>" 
						+ Locale.get("SeasonWindow.errors.name")+ "</html>");			
				getNameTextField().setBorder(new LineBorder(Color.red, 2));
				Toolkit.getDefaultToolkit().beep();
				return true;
			}			

		}

		return false;

	}


}  //  @jve:decl-index=0:visual-constraint="10,10"
