package gz.cyberbrain.cyberhotel.view.swing.start;

import gz.cyberbrain.cyberhotel.controller.BankListAdapter;
import gz.cyberbrain.cyberhotel.controller.BoardListAdapter;
import gz.cyberbrain.cyberhotel.controller.CardListAdapter;
import gz.cyberbrain.cyberhotel.controller.ConceptListAdapter;
import gz.cyberbrain.cyberhotel.controller.EmployeeListAdapter;
import gz.cyberbrain.cyberhotel.controller.PriceTypeListAdapter;
import gz.cyberbrain.cyberhotel.controller.RoomListAdapter;
import gz.cyberbrain.cyberhotel.controller.RoomTypeListAdapter;
import gz.cyberbrain.cyberhotel.controller.SeasonListAdapter;
import gz.cyberbrain.cyberhotel.view.swing.edit.AddressWindow;
import gz.cyberbrain.cyberhotel.view.swing.edit.BankingWindow;
import gz.cyberbrain.cyberhotel.view.swing.edit.BoardWindow;
import gz.cyberbrain.cyberhotel.view.swing.edit.CalendarWindow;
import gz.cyberbrain.cyberhotel.view.swing.edit.ConceptWindow;
import gz.cyberbrain.cyberhotel.view.swing.edit.EmployeeWindow;
import gz.cyberbrain.cyberhotel.view.swing.edit.ListWindow;
import gz.cyberbrain.cyberhotel.view.swing.edit.PriceTypeWindow;
import gz.cyberbrain.cyberhotel.view.swing.edit.PriceWindow;
import gz.cyberbrain.cyberhotel.view.swing.edit.RoomTypeWindow;
import gz.cyberbrain.cyberhotel.view.swing.edit.RoomWindow;
import gz.cyberbrain.cyberhotel.view.swing.edit.SeasonWindow;
import gz.cyberbrain.cyberhotel.view.swing.util.gui.CustomCellRenderer;
import gz.cyberbrain.cyberhotel.view.swing.util.gui.InfoPanel;
import gz.cyberbrain.cyberhotel.view.swing.util.locale.Locale;

import java.awt.Color;
import java.awt.Frame;
import java.awt.GraphicsEnvironment;
import java.awt.Rectangle;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.beans.PropertyVetoException;

import javax.swing.DefaultListCellRenderer;
import javax.swing.JDesktopPane;
import javax.swing.JFrame;
import javax.swing.JInternalFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;

public class MainWindow extends JFrame {

	private static final long serialVersionUID = 1L;	

	private static MainWindow mainWindow = null;

	private static ListWindow banksList = null;
	private static ListWindow cardsList = null;
	private static ListWindow roomTypesList = null;
	private static ListWindow roomsList = null;
	private static ListWindow boardsList = null;
	private static ListWindow priceTypesList = null;
	private static ListWindow seasonsList = null;
	private static ListWindow conceptsList = null;
	private static ListWindow employeesList = null;
	
	private JDesktopPane jDesktopPane = null;

	private JMenuBar hotelMenuBar = null;

	private JMenu hotelMenu = null;

	private JMenu editMenu = null;

	private JMenuItem exitMenuItem = null;

	private JMenuItem addressMenuItem = null;	 

	private JMenu bankingMenu = null;

	private JMenuItem banksMenuItem = null;

	private JMenuItem cardsMenuItem = null;

	private JMenu roomsMenu = null;

	private JMenuItem roomTypesMenuItem = null;

	private JMenuItem roomsMenuItem = null;

	private JMenu pricesMenu = null;

	private JMenuItem boardsMenuItem = null;

	private JMenuItem priceTypesMenuItem = null;

	private JMenuItem pricesMenuItem = null;

	private JMenuItem seasonsMenuItem = null;

	private JMenuItem conceptsMenuItem = null;

	private JMenuItem calendarMenuItem = null;
	
	private JMenuItem employeesMenuItem = null;

	/**
	 * This is the default constructor
	 */
	private MainWindow() {
		super();
		initialize();
	}

	public static MainWindow getInstance() {
		if (mainWindow == null) mainWindow = new MainWindow();
		return mainWindow;
	}

	/**
	 * This method initializes this
	 * 
	 * @return void
	 */
	private void initialize() {
		GraphicsEnvironment graphicsEnvironment=GraphicsEnvironment.getLocalGraphicsEnvironment();
		Rectangle maximumWindowBounds=graphicsEnvironment.getMaximumWindowBounds();

		this.setLocation(0,0);

		this.setSize(maximumWindowBounds.width, maximumWindowBounds.height);
		this.setMaximizedBounds(maximumWindowBounds);
		this.setState(Frame.NORMAL);

		this.setTitle(Locale.get("MainWindow.title"));		
		this.setContentPane(getJDesktopPane());			
		this.setDefaultCloseOperation(EXIT_ON_CLOSE);
		this.setJMenuBar(getJJMenuBar());				
	}

	private JDesktopPane getJDesktopPane() {
		if (jDesktopPane == null) {
			jDesktopPane = new JDesktopPane();
			jDesktopPane.setDragMode(JDesktopPane.OUTLINE_DRAG_MODE);
			jDesktopPane.setBackground(Color.LIGHT_GRAY);
		}
		return jDesktopPane;
	}

	/**
	 * This method initializes hotelMenuBar	
	 * 	
	 * @return javax.swing.JMenuBar	
	 */
	private JMenuBar getJJMenuBar() {
		if (hotelMenuBar == null) {
			hotelMenuBar = new JMenuBar();			
			hotelMenuBar.add(getHotelMenu());			
			hotelMenuBar.add(getEditMenu());
		}
		return hotelMenuBar;
	}

	/**
	 * This method initializes hotelMenu	
	 * 	
	 * @return javax.swing.JMenu	
	 */
	private JMenu getHotelMenu() {
		if (hotelMenu == null) {
			hotelMenu = new JMenu();
			hotelMenu.setText(Locale.get("MainWindow.hotelMenu"));
			hotelMenu.setMnemonic(KeyEvent.VK_H);
			hotelMenu.add(getExitMenuItem());
		}
		return hotelMenu;
	}

	/**
	 * This method initializes editMenu	
	 * 	
	 * @return javax.swing.JMenu	
	 */
	private JMenu getEditMenu() {
		if (editMenu == null) {
			editMenu = new JMenu();
			editMenu.setText(Locale.get("MainWindow.editMenu"));
			editMenu.setMnemonic(KeyEvent.VK_E);
			editMenu.add(getAddressMenuItem());			
			editMenu.add(getBankingMenu());
			editMenu.add(getRoomsMenu());			
			editMenu.add(getPricesMenu());						
			editMenu.add(getConceptsMenuItem());
			editMenu.add(getEmloyeesMenuItem());
			editMenu.addSeparator();
			editMenu.add(getCalendarMenuItem());
		}
		return editMenu;
	}

	private JMenuItem getEmloyeesMenuItem() {
		if (employeesMenuItem == null) {
			employeesMenuItem = new JMenuItem();
			employeesMenuItem.setText(Locale.get("MainWindow.employeesMenuItem"));
			employeesMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					if (employeesList == null) {

						InfoPanel ipanel = new InfoPanel();
						InfoPanel ipanel2 = new InfoPanel();

						EmployeeWindow employeeWindow =  EmployeeWindow.getInstance();					

						ipanel2.setBounds(0,0,employeeWindow.getWidth(),50);
						ipanel2.setInfoText(Locale.get("EmployeeWindow.infoText"));
						employeeWindow.setInfoPanel(ipanel2);
						employeeWindow.setTitle(Locale.get("EmployeeWindow.title"));					

						ListWindow listWindow = new ListWindow();
						listWindow.setAdapter(new EmployeeListAdapter());
						listWindow.setCellRenderer(new DefaultListCellRenderer());
						listWindow.loadList();
						listWindow.setChild(employeeWindow);
						employeeWindow.setOwner(listWindow);
						ipanel.setBounds(0,0,listWindow.getWidth(),50);
						ipanel.setInfoText(Locale.get("ListWindow.Employees.infoText"));
						listWindow.setInfoPanel(ipanel);
						listWindow.setTitle(Locale.get("ListWindow.Employees.title"));						
						getContentPane().add(listWindow);
						listWindow.setVisible(true);
						employeesList = listWindow;

					} else {

						employeesList.loadList();					
						showInDesktopPane(employeesList);

					}

				}
			});

		}
		return employeesMenuItem;

	}

	/**
	 * This method initializes exitMenuItem	
	 * 	
	 * @return javax.swing.JMenuItem	
	 */
	private JMenuItem getExitMenuItem() {
		if (exitMenuItem == null) {
			exitMenuItem = new JMenuItem();
			exitMenuItem.setText(Locale.get("MainWindow.exitMenuItem"));
			exitMenuItem.setMnemonic(KeyEvent.VK_S);
			exitMenuItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_F4,InputEvent.ALT_MASK));			
			exitMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					MainWindow mainWindow = MainWindow.getInstance();														
					mainWindow.setVisible(false);
					mainWindow.dispose();
					System.exit(0);

				}
			});
		}
		return exitMenuItem;
	}

	/**
	 * This method initializes addressMenuItem	
	 * 	
	 * @return javax.swing.JMenuItem	
	 */
	private JMenuItem getAddressMenuItem() {
		if (addressMenuItem == null) {
			addressMenuItem = new JMenuItem();
			addressMenuItem.setText(Locale.get("MainWindow.addressMenuItem"));
			addressMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					InfoPanel ipanel = new InfoPanel();
					ipanel.setInfoText(Locale.get("AddressWindow.infoText"));

					AddressWindow addressWindow = AddressWindow.getInstance();					
					addressWindow.setTitle(Locale.get("AddressWindow.title"));
					ipanel.setBounds(0,0,addressWindow.getWidth(),50);
					addressWindow.setInfoPanel(ipanel);

					showInDesktopPane(addressWindow);

				}
			});
		}
		return addressMenuItem;
	}

	/**
	 * This method initializes bankingMenuItem	
	 * 	
	 * @return javax.swing.JMenuItem	
	 */


	private JMenu getBankingMenu() {
		if (bankingMenu == null) {
			bankingMenu = new JMenu();
			bankingMenu.setText(Locale.get("MainWindow.bankingMenu"));
			bankingMenu.add(getBanksMenuItem());
			bankingMenu.add(getCardsMenuItem());
		}
		return bankingMenu;
	}

	private JMenuItem getBanksMenuItem() {
		if (banksMenuItem == null) {
			banksMenuItem = new JMenuItem();
			banksMenuItem.setText(Locale.get("MainWindow.banksMenuItem"));
			banksMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					if (banksList == null) {

						InfoPanel ipanel = new InfoPanel();	
						InfoPanel ipanel2 = new InfoPanel();

						BankingWindow bankingWindow = new BankingWindow();
						bankingWindow.setTitle(Locale.get("BankingWindow.Banks.title"));

						ipanel2.setBounds(0,0,bankingWindow.getWidth(),50);
						ipanel2.setInfoText(Locale.get("BankingWindow.Banks.infoText"));
						bankingWindow.setInfoPanel(ipanel2);
						bankingWindow.setDialogMessage(Locale.get("JOptionPane.BankingWindow.saveButton.bankMessage.ok"));
						bankingWindow.setDialogTitle(Locale.get("JOptionPane.BankingWindow.saveButton.bankTitle.ok"));

						ListWindow listWindow = new ListWindow();
						listWindow.setAdapter(new BankListAdapter());
						listWindow.setCellRenderer(new CustomCellRenderer());
						listWindow.loadList();
						listWindow.setChild(bankingWindow);
						bankingWindow.setOwner(listWindow);
						ipanel.setBounds(0,0,listWindow.getWidth(),50);
						ipanel.setInfoText(Locale.get("ListWindow.Banks.infoText"));
						listWindow.setInfoPanel(ipanel);					
						listWindow.setTitle(Locale.get("ListWindow.Banks.title"));											
						getContentPane().add(listWindow);
						listWindow.setVisible(true);
						banksList = listWindow;						
					} else {						

						banksList.setAdapter(new BankListAdapter());
						banksList.loadList();		
						showInDesktopPane(banksList);

					}

				}
			});

		}
		return banksMenuItem;
	}

	private JMenuItem getCardsMenuItem() {
		if (cardsMenuItem == null) {
			cardsMenuItem = new JMenuItem();
			cardsMenuItem.setText(Locale.get("MainWindow.cardsMenuItem"));
			cardsMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					if (cardsList == null) {

						InfoPanel ipanel = new InfoPanel();					
						InfoPanel ipanel2 = new InfoPanel();

						BankingWindow bankingWindow = new BankingWindow();
						bankingWindow.setTitle(Locale.get("BankingWindow.Cards.title"));

						ipanel2.setBounds(0,0,bankingWindow.getWidth(),50);
						ipanel2.setInfoText(Locale.get("BankingWindow.Cards.infoText"));
						bankingWindow.setInfoPanel(ipanel2);						
						bankingWindow.setDialogMessage(Locale.get("JOptionPane.BankingWindow.saveButton.cardMessage"));
						bankingWindow.setDialogTitle(Locale.get("JOptionPane.BankingWindow.saveButton.cardTitle"));

						ListWindow listWindow = new ListWindow();
						listWindow.setAdapter(new CardListAdapter());
						listWindow.setCellRenderer(new CustomCellRenderer());
						listWindow.loadList();						
						listWindow.setChild(bankingWindow);
						bankingWindow.setOwner(listWindow);
						ipanel.setBounds(0,0,listWindow.getWidth(),50);
						ipanel.setInfoText(Locale.get("ListWindow.Cards.infoText"));					
						listWindow.setInfoPanel(ipanel);
						listWindow.setTitle(Locale.get("ListWindow.Cards.title"));						
						getContentPane().add(listWindow);
						listWindow.setVisible(true);
						cardsList = listWindow;
					} else {					
						cardsList.setAdapter(new CardListAdapter());
						cardsList.loadList();
						showInDesktopPane(cardsList);
					}

				}
			});

		}
		return cardsMenuItem;
	}

	/**
	 * This method initializes roomsMenu	
	 * 	
	 * @return javax.swing.JMenu	
	 */
	private JMenu getRoomsMenu() {
		if (roomsMenu == null) {
			roomsMenu = new JMenu();
			roomsMenu.setText(Locale.get("MainWindow.roomsMenu"));
			roomsMenu.add(getRoomTypesMenuItem());
			roomsMenu.add(getRoomsMenuItem());
		}
		return roomsMenu;
	}

	private JMenuItem getRoomTypesMenuItem() {
		if (roomTypesMenuItem == null) {
			roomTypesMenuItem = new JMenuItem();
			roomTypesMenuItem.setText(Locale.get("MainWindow.roomTypesMenuItem"));
			roomTypesMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					if (roomTypesList == null) {

						InfoPanel ipanel = new InfoPanel();
						InfoPanel ipanel2 = new InfoPanel();

						RoomTypeWindow roomTypeWindow = RoomTypeWindow.getInstance(); 

						ipanel2.setBounds(0,0,roomTypeWindow.getWidth(),50);
						ipanel2.setInfoText(Locale.get("RoomTypeWindow.infoText"));
						roomTypeWindow.setInfoPanel(ipanel2);
						roomTypeWindow.setTitle(Locale.get("RoomTypeWindow.title"));	
						roomTypeWindow.setDialogMessage(Locale.get("JOptionPane.RoomTypeWindow.saveButton.message"));
						roomTypeWindow.setDialogTitle(Locale.get("JOptionPane.RoomTypeWindow.saveButton.title"));

						ListWindow listWindow = new ListWindow();
						listWindow.setAdapter(new RoomTypeListAdapter());
						listWindow.setCellRenderer(new DefaultListCellRenderer());
						listWindow.loadList();						
						listWindow.setChild(roomTypeWindow);
						roomTypeWindow.setOwner(listWindow);
						ipanel.setBounds(0,0,listWindow.getWidth(),50);
						ipanel.setInfoText(Locale.get("ListWindow.RoomTypes.infoText"));
						listWindow.setInfoPanel(ipanel);
						listWindow.setTitle(Locale.get("ListWindow.RoomTypes.title"));						
						getContentPane().add(listWindow);
						listWindow.setVisible(true);
						roomTypesList = listWindow;

					} else {

						roomTypesList.loadList();						
						showInDesktopPane(roomTypesList);

					}

				}
			});
		}
		return roomTypesMenuItem;
	}

	private JMenuItem getRoomsMenuItem() {
		if (roomsMenuItem == null) {
			roomsMenuItem = new JMenuItem();
			roomsMenuItem.setText(Locale.get("MainWindow.roomsMenuItem"));
			roomsMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					if (roomsList == null) {

						InfoPanel ipanel = new InfoPanel();
						InfoPanel ipanel2 = new InfoPanel();

						RoomWindow roomWindow = RoomWindow.getInstance();

						ipanel2.setBounds(0,0,roomWindow.getWidth(),50);
						ipanel2.setInfoText(Locale.get("RoomWindow.infoText"));
						roomWindow.setInfoPanel(ipanel2);
						roomWindow.setTitle(Locale.get("RoomWindow.title"));
						roomWindow.setDialogMessage(Locale.get("JOptionPane.RoomWindow.saveButton.message"));
						roomWindow.setDialogTitle(Locale.get("JOptionPane.RoomWindow.saveButton.title"));


						ListWindow listWindow = new ListWindow();
						listWindow.setAdapter(new RoomListAdapter());
						listWindow.setCellRenderer(new DefaultListCellRenderer());
						listWindow.loadList();						
						listWindow.setChild(roomWindow);
						roomWindow.setOwner(listWindow);
						ipanel.setBounds(0,0,listWindow.getWidth(),50);
						ipanel.setInfoText(Locale.get("ListWindow.Rooms.infoText"));
						listWindow.setInfoPanel(ipanel);
						listWindow.setTitle(Locale.get("ListWindow.Rooms.title"));
						getContentPane().add(listWindow);
						listWindow.setVisible(true);
						roomsList = listWindow;		

					} else {

						roomsList.loadList();						
						showInDesktopPane(roomsList);

					}

				}
			});

		}
		return roomsMenuItem;
	}

	/**
	 * This method initializes pricesMenu	
	 * 	
	 * @return javax.swing.JMenu	
	 */
	private JMenu getPricesMenu() {
		if (pricesMenu == null) {
			pricesMenu = new JMenu();
			pricesMenu.setText(Locale.get("MainWindow.pricesMenu"));
			pricesMenu.add(getBoardsMenuItem());
			pricesMenu.add(getPriceTypesMenuItem());
			pricesMenu.add(getSeasonsMenuItem());
			pricesMenu.addSeparator();
			pricesMenu.add(getPricesMenuItem());
		}
		return pricesMenu;
	}

	private JMenuItem getBoardsMenuItem() {
		if (boardsMenuItem == null) {
			boardsMenuItem = new JMenuItem();
			boardsMenuItem.setText(Locale.get("MainWindow.boardsMenuItem"));
			boardsMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					if (boardsList == null) {

						InfoPanel ipanel = new InfoPanel();
						InfoPanel ipanel2 = new InfoPanel();

						BoardWindow boardWindow =  BoardWindow.getInstance();					

						ipanel2.setBounds(0,0,boardWindow.getWidth(),50);
						ipanel2.setInfoText(Locale.get("BoardWindow.infoText"));
						boardWindow.setInfoPanel(ipanel2);
						boardWindow.setTitle(Locale.get("BoardWindow.title"));
						boardWindow.setDialogMessage(Locale.get("JOptionPane.BoardWindow.saveButton.message"));
						boardWindow.setDialogTitle(Locale.get("JOptionPane.BoardWindow.saveButton.title"));

						ListWindow listWindow = new ListWindow();
						listWindow.setAdapter(new BoardListAdapter());
						listWindow.setCellRenderer(new DefaultListCellRenderer());
						listWindow.loadList();						
						listWindow.setChild(boardWindow);
						boardWindow.setOwner(listWindow);
						ipanel.setBounds(0,0,listWindow.getWidth(),50);
						ipanel.setInfoText(Locale.get("ListWindow.Boards.infoText"));
						listWindow.setInfoPanel(ipanel);
						listWindow.setTitle(Locale.get("ListWindow.Boards.title"));
						getContentPane().add(listWindow);
						listWindow.setVisible(true);
						boardsList = listWindow;											

					} else {

						boardsList.loadList();								
						showInDesktopPane(boardsList);

					}
				}
			});
		}
		return boardsMenuItem;
	}

	private JMenuItem getPriceTypesMenuItem() {
		if (priceTypesMenuItem == null) {
			priceTypesMenuItem = new JMenuItem();
			priceTypesMenuItem.setText(Locale.get("MainWindow.priceTypesMenuItem"));
			priceTypesMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					if (priceTypesList == null) {

						InfoPanel ipanel = new InfoPanel();
						InfoPanel ipanel2 = new InfoPanel();

						PriceTypeWindow priceTypeWindow =  PriceTypeWindow.getInstance();					

						ipanel2.setBounds(0,0,priceTypeWindow.getWidth(),50);
						ipanel2.setInfoText(Locale.get("PriceTypeWindow.infoText"));
						priceTypeWindow.setInfoPanel(ipanel2);
						priceTypeWindow.setTitle(Locale.get("PriceTypeWindow.title"));
						priceTypeWindow.setDialogMessage(Locale.get("JOptionPane.PriceTypeWindow.saveButton.message"));
						priceTypeWindow.setDialogTitle(Locale.get("JOptionPane.PriceTypeWindow.saveButton.title"));


						ListWindow listWindow = new ListWindow();
						listWindow.setAdapter(new PriceTypeListAdapter());
						listWindow.setCellRenderer(new DefaultListCellRenderer());
						listWindow.loadList();
						listWindow.setChild(priceTypeWindow);
						priceTypeWindow.setOwner(listWindow);
						ipanel.setBounds(0,0,listWindow.getWidth(),50);
						ipanel.setInfoText(Locale.get("ListWindow.PriceTypes.infoText"));
						listWindow.setInfoPanel(ipanel);
						listWindow.setTitle(Locale.get("ListWindow.PriceTypes.title"));
						getContentPane().add(listWindow);
						listWindow.setVisible(true);
						priceTypesList = listWindow;								

					} else {

						priceTypesList.loadList();					
						showInDesktopPane(priceTypesList);

					}

				}
			});
		}
		return priceTypesMenuItem;
	}

	private JMenuItem getPricesMenuItem() {
		if (pricesMenuItem == null) {
			pricesMenuItem = new JMenuItem();
			pricesMenuItem.setText(Locale.get("MainWindow.pricesMenuItem"));
			pricesMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					InfoPanel ipanel = new InfoPanel();

					PriceWindow priceWindow =  PriceWindow.getInstance();					

					ipanel.setBounds(0,0,priceWindow.getWidth(),50);
					ipanel.setInfoText(Locale.get("PriceWindow.infoText"));
					priceWindow.setInfoPanel(ipanel);
					priceWindow.setTitle(Locale.get("PriceWindow.title"));
					priceWindow.setDialogMessage(Locale.get("JOptionPane.PriceWindow.delButton.message"));
					priceWindow.setDialogTitle(Locale.get("JOptionPane.PriceWindow.delButton.title"));

					showInDesktopPane(priceWindow);	

				}
			});

		}
		return pricesMenuItem;
	}

	private JMenuItem getSeasonsMenuItem() {
		if (seasonsMenuItem == null) {
			seasonsMenuItem = new JMenuItem();
			seasonsMenuItem.setText(Locale.get("MainWindow.seasonsMenuItem"));
			seasonsMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					if (seasonsList == null) {

						InfoPanel ipanel = new InfoPanel();
						InfoPanel ipanel2 = new InfoPanel();

						SeasonWindow seasonWindow =  SeasonWindow.getInstance();					

						ipanel2.setBounds(0,0,seasonWindow.getWidth(),50);
						ipanel2.setInfoText(Locale.get("SeasonWindow.infoText"));
						seasonWindow.setInfoPanel(ipanel2);
						seasonWindow.setTitle(Locale.get("SeasonWindow.title"));
						seasonWindow.setDialogMessage(Locale.get("JOptionPane.SeasonWindow.saveButton.message"));
						seasonWindow.setDialogTitle(Locale.get("JOptionPane.SeasonWindow.saveButton.title"));

						ListWindow listWindow = new ListWindow();
						listWindow.setAdapter(new SeasonListAdapter());
						listWindow.setCellRenderer(new DefaultListCellRenderer());
						listWindow.loadList();
						listWindow.setChild(seasonWindow);
						seasonWindow.setOwner(listWindow);
						ipanel.setBounds(0,0,listWindow.getWidth(),50);
						ipanel.setInfoText(Locale.get("ListWindow.Seasons.infoText"));
						listWindow.setInfoPanel(ipanel);
						listWindow.setTitle(Locale.get("ListWindow.Seasons.title"));
						listWindow.setVisible(true);
						getContentPane().add(listWindow);
						listWindow.setVisible(true);
						seasonsList = listWindow;

					} else {

						seasonsList.loadList();					
						showInDesktopPane(seasonsList);

					}

				}
			});

		}
		return seasonsMenuItem;
	}	 

	/**
	 * This method initializes conceptsMenuItem	
	 * 	
	 * @return javax.swing.JMenuItem	
	 */
	private JMenuItem getConceptsMenuItem() {
		if (conceptsMenuItem == null) {
			conceptsMenuItem = new JMenuItem();
			conceptsMenuItem.setText(Locale.get("MainWindow.conceptsMenuItem"));
			conceptsMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					if (conceptsList == null) {

						InfoPanel ipanel = new InfoPanel();
						InfoPanel ipanel2 = new InfoPanel();

						ConceptWindow conceptWindow =  ConceptWindow.getInstance();					

						ipanel2.setBounds(0,0,conceptWindow.getWidth(),50);
						ipanel2.setInfoText(Locale.get("ConceptWindow.infoText"));
						conceptWindow.setInfoPanel(ipanel2);
						conceptWindow.setTitle(Locale.get("ConceptWindow.title"));					

						ListWindow listWindow = new ListWindow();
						listWindow.setAdapter(new ConceptListAdapter());
						listWindow.setCellRenderer(new DefaultListCellRenderer());
						listWindow.loadList();
						listWindow.setChild(conceptWindow);
						conceptWindow.setOwner(listWindow);
						ipanel.setBounds(0,0,listWindow.getWidth(),50);
						ipanel.setInfoText(Locale.get("ListWindow.Concepts.infoText"));
						listWindow.setInfoPanel(ipanel);
						listWindow.setTitle(Locale.get("ListWindow.Concepts.title"));						
						getContentPane().add(listWindow);
						listWindow.setVisible(true);
						conceptsList = listWindow;

					} else {

						conceptsList.loadList();					
						showInDesktopPane(conceptsList);

					}

				}
			});

		}
		return conceptsMenuItem;
	}

	public JMenuItem getCalendarMenuItem() {
		if (calendarMenuItem == null) {
			calendarMenuItem = new JMenuItem();
			calendarMenuItem.setText(Locale.get("MainWindow.calendarMenuItem"));
			calendarMenuItem.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {

					InfoPanel ipanel = new InfoPanel();

					CalendarWindow calendarWindow =  CalendarWindow.getInstance();					

					calendarWindow.setInfoPanel(ipanel);
					calendarWindow.setTitle(Locale.get("CalendarWindow.title"));						
					ipanel.setBounds(0,0,calendarWindow.getWidth(),50);						

					showInDesktopPane(calendarWindow);
					
				}
			});

		}
		return calendarMenuItem;
	}

	public void showInDesktopPane(JInternalFrame frame) {

		if (frame.isIcon()) {
			try {
				frame.setIcon(false);
			} catch (PropertyVetoException e) {}
		} else {			 
			if (!frame.isVisible()) {								 
				getContentPane().remove(frame);
				getContentPane().add(frame);				
				frame.setVisible(true);		
			}
		}

		try {
			frame.setSelected(true);
		} catch (java.beans.PropertyVetoException e) {}

	}

}  //  @jve:decl-index=0:visual-constraint="10,4"
;